Coverage for /media/ldata/code/tendril/tendril/scripts/testresult.py: 0%

# Coverage for /media/ldata/code/tendril/tendril/scripts/testresult.py : 0%

## 10 statements 0 run 10 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 | """ This file is part of tendril See the COPYING, README, and INSTALL files for more information """ import sys from tendril.testing import analysis from tendril.utils.db import get_session def main(serialno=None): with get_session() as s: suites = analysis.get_test_suite_objects(serialno=serialno, session=s) for suite in suites: suite.finish() if __name__ == '__main__': main(serialno=sys.argv[1])